import React, { useCallback, useState } from 'react';
import RenderFields from '../../RenderFields';
import withCondition from '../../withCondition';
import { fieldAffectsData } from '../../../../../fields/config/types';
import { Collapsible } from '../../../elements/Collapsible';
import toKebabCase from '../../../../../utilities/toKebabCase';
import { usePreferences } from '../../../utilities/Preferences';
import { useDocumentInfo } from '../../../utilities/DocumentInfo';
import FieldDescription from '../../FieldDescription';
import './index.scss';
const baseClass = 'collapsible-field';
const CollapsibleField = (props) => {
    var _a;
    const { label, fields, fieldTypes, path, permissions, admin: { readOnly, className, description, }, } = props;
    const { getPreference, setPreference } = usePreferences();
    const { preferencesKey, preferences } = useDocumentInfo();
    const [fieldPreferencesKey] = useState(() => `collapsible-${toKebabCase(label)}`);
    const onToggle = useCallback(async (newCollapsedState) => {
        var _a;
        const existingPreferences = await getPreference(preferencesKey);
        setPreference(preferencesKey, {
            ...existingPreferences,
            fields: {
                ...(existingPreferences === null || existingPreferences === void 0 ? void 0 : existingPreferences.fields) || {},
                [fieldPreferencesKey]: {
                    ...(_a = existingPreferences === null || existingPreferences === void 0 ? void 0 : existingPreferences.fields) === null || _a === void 0 ? void 0 : _a[fieldPreferencesKey],
                    collapsed: newCollapsedState,
                },
            },
        });
    }, [preferencesKey, fieldPreferencesKey, getPreference, setPreference]);
    return (React.createElement(React.Fragment, null,
        React.createElement(Collapsible, { initCollapsed: Boolean((_a = preferences.fields[fieldPreferencesKey]) === null || _a === void 0 ? void 0 : _a.collapsed), className: [
                'field-type',
                baseClass,
                className,
            ].filter(Boolean).join(' '), header: React.createElement("div", { className: `${baseClass}__label` }, label), onToggle: onToggle },
            React.createElement(RenderFields, { forceRender: true, readOnly: readOnly, permissions: permissions === null || permissions === void 0 ? void 0 : permissions.fields, fieldTypes: fieldTypes, fieldSchema: fields.map((field) => ({
                    ...field,
                    path: `${path ? `${path}.` : ''}${fieldAffectsData(field) ? field.name : ''}`,
                })) })),
        React.createElement(FieldDescription, { description: description })));
};
export default withCondition(CollapsibleField);
